# **METAVOID WRAPPER**


_This is a an official Wrapper for matavoid Api. To let users to use api with ease._


## Examples:

To get language translation 

```
from metaapi import META
x = META()
print(x.translate("hello", "hi"))
```

To get wallpaper images

```
from metaapi import META
x = META()
print(x.wallpaper("alphacoder", "Pokemon", "1"))
```

```
from metaapi import META
x = META()
print(x.wallpaper("wallhaven", "Pokemon", "1"))
```

To get anime images

```
from metaapi import META
x = META()
print(x.animeimage("sfw", "slap"))
```

To get youtube dl

```
from metaapi import META
x = META()
print(x.yt_dl("https://youtu.be/jzD_yyEcp0M"))
```

To get facebook dl

```
from metaapi import META
x = META()
print(x.fb_dl("https://www.facebook.com/watch/1424858414264105/&ved=2ahUKEwjQ1b6Vt9D3AhXLSWwGHd2rDxEQo7QBegQIAxAB&usg=AOvVaw0Cw1hhGO9eVB5PUERZGeY6"))
```

To get instagram dl

```
from metaapi import META
x = META()
print(x.insta_dl("https://www.instagram.com/reel/Cc3MP9YBmNX/?igshid=YmMyMTA2M2Y="))
```

To get twiter dl

```
from metaapi import META
x = META()
print(x.twitter_dl("https://twitter.com/2020Fights/status/1521209796782919680?s=20&t=b8YyzXIkHfrbEwMfcZZI7A"))
```

To get  Wikipedia 


```
from metaapi import META
x = META()
print(x.wiki("pokemon", "en"))
```

To get urban 


```
from metaapi import META
x = META()
print(x.urban("pokemon", "1"))
```

To get urban random


```
from metaapi import META
x = META()
print(x.urban_random())
```

To get manga search


```
from metaapi import META
x = META()
print(x.manga_search("pokemon", "1"))
```

To get manga detail


```
from metaapi import META
x = META()
print(x.manga_detail("manga-sb969684"))
```

To get manga dl


```
from metaapi import META
x = META()
print(x.mangadl("manga-sb969684", "2"))
```

To get gogoanime dl


```
from metaapi import META
x = META()
print(x.gogoanimedl("pokemon-xy-episode-2"))
```

To get torrent nyaa


```
from metaapi import META
x = META()
print(x.torrent_nyaa("pokemon", "1"))
```

To get torrent 1337x


```
from metaapi import META
x = META()
print(x.torrent_nyaa("pokemon", "1"))
```

To get talk chatbot


```
from metaapi import META
x = META()
print(x.chatbot("hi"))
```

<i>Checkout code at <a href="github.com/metavoidteam/MetaApi-Py/blob/master/main.py">main.py</a></i>
